use serde::{Deserialize, Serialize};
use uuid::Uuid;

// The post as it is received from the client
#[derive(Debug, Serialize, Deserialize)]
pub struct NewPost {
    content: String,
    token: String,
}

// The post as it is stored in the database
#[derive(Debug, Serialize, Deserialize, Clone)]
pub struct Post {
    pub uuid: Uuid,
    pub content: String,
    pub votes: VoteCount,
}

impl From<NewPost> for Post {
    fn from(post: NewPost) -> Self {
        Self {
            uuid: Uuid::new_v4(),
            content: post.content,
            votes: VoteCount::new(),
        }
    }
}

// Part of the post struct
#[derive(Debug, Serialize, Deserialize, Clone)]
pub struct VoteCount {
    pub up: u32,
    pub down: u32,
}

impl VoteCount {
    fn new() -> Self {
        Self { up: 0, down: 0 }
    }
}
